# CMeel gettext

[![PyPI version](https://badge.fury.io/py/cmeel-gettext.svg)](https://pypi.org/project/cmeel-gettext)
[![Release](https://github.com/cmake-wheel/cmeel-gettext/actions/workflows/release.yml/badge.svg)](https://github.com/cmake-wheel/cmeel-gettext/actions/workflows/release.yml)

[gettext](https://www.gnu.org/software/gettext/) distribution for cmeel packages.
